@@ -1,9 +1,14 @@
-from typing import Any, Literal
+from typing import Any
 from uuid import UUID
 
 from ._base import DirtyEquals
 from ._utils import plain_repr
 
+try:
+    from typing import Literal
+except ImportError:
+    from typing_extensions import Literal  # type: ignore[misc]
+
 
 class IsUUID(DirtyEquals[UUID]):
     def __init__(self, version: Literal[None, 1, 2, 3, 4, 5] = None):
